@@ -1,44 +1,77 @@
 """CLI
 """
+import logging
 import os
 import sys
 
 import click
-import ndebug
+import click_log
 
 from semantic_release import ci_checks
 from semantic_release.errors import GitError, ImproperConfigurationError
 
 from .dist import build_dists, remove_dists
-from .history import (evaluate_version_bump, get_current_version, get_new_version,
-                      get_previous_version, set_new_version)
+from .history import (
+    evaluate_version_bump,
+    get_current_version,
+    get_new_version,
+    get_previous_version,
+    set_new_version,
+)
 from .history.logs import generate_changelog, markdown_changelog
-from .hvcs import (check_build_status, check_token, get_domain, get_token, post_changelog,
-                   upload_to_release)
+from .hvcs import (
+    check_build_status,
+    check_token,
+    get_domain,
+    get_token,
+    post_changelog,
+    upload_to_release,
+)
 from .pypi import upload_to_pypi
 from .settings import config, overload_configuration
-from .vcs_helpers import (checkout, commit_new_version, get_current_head_hash,
-                          get_repository_owner_and_name, push_new_version, tag_new_version)
+from .vcs_helpers import (
+    checkout,
+    commit_new_version,
+    get_current_head_hash,
+    get_repository_owner_and_name,
+    push_new_version,
+    tag_new_version,
+)
 
-debug = ndebug.create(__name__)
+logger = logging.getLogger("semantic_release")
+click_log.basic_config(logger)
 
 SECRET_NAMES = [
-    'PYPI_USERNAME',
-    'PYPI_PASSWORD',
-    'GH_TOKEN',
-    'GL_TOKEN',
+    "PYPI_USERNAME",
+    "PYPI_PASSWORD",
+    "GH_TOKEN",
+    "GL_TOKEN",
 ]
 
 COMMON_OPTIONS = [
-    click.option('--major', 'force_level', flag_value='major', help='Force major version.'),
-    click.option('--minor', 'force_level', flag_value='minor', help='Force minor version.'),
-    click.option('--patch', 'force_level', flag_value='patch', help='Force patch version.'),
-    click.option('--post', is_flag=True, help='Post changelog.'),
-    click.option('--retry', is_flag=True, help='Retry the same release, do not bump.'),
-    click.option('--noop', is_flag=True,
-                 help='No-operations mode, finds the new version number without changing it.'),
-    click.option('--define', '-D', multiple=True,
-                 help='setting="value", override a configuration value'),
+    click_log.simple_verbosity_option(logger),
+    click.option(
+        "--major", "force_level", flag_value="major", help="Force major version."
+    ),
+    click.option(
+        "--minor", "force_level", flag_value="minor", help="Force minor version."
+    ),
+    click.option(
+        "--patch", "force_level", flag_value="patch", help="Force patch version."
+    ),
+    click.option("--post", is_flag=True, help="Post changelog."),
+    click.option("--retry", is_flag=True, help="Retry the same release, do not bump."),
+    click.option(
+        "--noop",
+        is_flag=True,
+        help="No-operations mode, finds the new version number without changing it.",
+    ),
+    click.option(
+        "--define",
+        "-D",
+        multiple=True,
+        help='setting="value", override a configuration value',
+    ),
     overload_configuration,
 ]
 
@@ -60,40 +93,39 @@ def version(**kwargs):
     """
     retry = kwargs.get("retry")
     if retry:
-        click.echo('Retrying publication of the same version...')
+        logger.info("Retrying publication of the same version")
     else:
-        click.echo('Creating new version.')
+        logger.info("Creating new version")
 
     # Get the current version number
     try:
         current_version = get_current_version()
-        click.echo('Current version: {0}'.format(current_version))
+        logger.info("Current version: {0}".format(current_version))
     except GitError as e:
-        click.echo(click.style(str(e), 'red'), err=True)
+        logger.error(str(e))
         return False
     # Find what the new version number should be
-    level_bump = evaluate_version_bump(current_version, kwargs['force_level'])
+    level_bump = evaluate_version_bump(current_version, kwargs["force_level"])
     new_version = get_new_version(current_version, level_bump)
 
     if new_version == current_version and not retry:
-        click.echo(click.style('No release will be made.', fg='yellow'))
+        logger.info("No release will be made.")
         return False
 
-    if kwargs['noop'] is True:
-        click.echo('{0} Should have bumped from {1} to {2}.'.format(
-            click.style('No operation mode.', fg='yellow'),
-            current_version,
-            new_version
-        ))
+    if kwargs["noop"] is True:
+        logger.warning(
+            "No operation mode. Should have bumped "
+            f"from {current_version} to {new_version}"
+        )
         return False
 
-    if config.getboolean('semantic_release', 'check_build_status'):
-        click.echo('Checking build status...')
+    if config.getboolean("semantic_release", "check_build_status"):
+        logger.info("Checking build status...")
         owner, name = get_repository_owner_and_name()
         if not check_build_status(owner, name, get_current_head_hash()):
-            click.echo(click.style('The build has failed', 'red'))
+            logger.warning("The build failed, cancelling the release")
             return False
-        click.echo(click.style('The build was a success, continuing the release', 'green'))
+        logger.info("The build was a success, continuing the release")
 
     if retry:
         # No need to make changes to the repo, we're just retrying.
@@ -101,12 +133,15 @@ def version(**kwargs):
 
     # Bump the version
     set_new_version(new_version)
-    if config.get('semantic_release', 'commit_version_number', fallback=(
-        config.get('semantic_release', 'version_source') == 'commit')
+    if config.get(
+        "semantic_release",
+        "commit_version_number",
+        fallback=(config.get("semantic_release", "version_source") == "commit"),
     ):
         commit_new_version(new_version)
     tag_new_version(new_version)
-    click.echo('Bumping with a {0} version to {1}.'.format(level_bump, new_version))
+
+    logger.info(f"Bumping with a {level_bump} version to {new_version}")
     return True
 
 
@@ -123,63 +158,57 @@ def changelog(**kwargs):
             "Make sure semantic_release.version_variable "
             "is setup correctly"
         )
-    else:
-        debug('changelog got current_version', current_version)
 
     previous_version = get_previous_version(current_version)
-    debug('changelog got previous_version', previous_version)
 
     # Generate the changelog
-    if kwargs['unreleased']:
+    if kwargs["unreleased"]:
         log = generate_changelog(current_version, None)
     else:
         log = generate_changelog(previous_version, current_version)
-    click.echo(markdown_changelog(current_version, log, header=False))
+    logger.info(markdown_changelog(current_version, log, header=False))
 
     # Post changelog to HVCS if enabled
-    debug('noop={}, post={}'.format(kwargs.get('noop'), kwargs.get('post')))
-    if not kwargs.get('noop') and kwargs.get('post'):
+    if not kwargs.get("noop") and kwargs.get("post"):
         if check_token():
             owner, name = get_repository_owner_and_name()
-            click.echo('Updating changelog')
+            logger.info("Posting changelog to HVCS")
             post_changelog(
                 owner,
                 name,
                 current_version,
-                markdown_changelog(current_version, log, header=False)
+                markdown_changelog(current_version, log, header=False),
             )
         else:
-            click.echo(
-                click.style('Missing token: cannot post changelog', 'red'), err=True)
+            logger.error("Missing token: cannot post changelog to HVCS")
 
 
 def publish(**kwargs):
     """Run the version task, then push to git and upload to PyPI / GitHub Releases."""
     current_version = get_current_version()
-    click.echo('Current version: {0}'.format(current_version))
 
-    retry = kwargs.get('retry')
+    retry = kwargs.get("retry")
     if retry:
-        debug('publish: retry is on')
+        logger.info("Retry is on")
         # The "new" version will actually be the current version, and the
         # "current" version will be the previous version.
         new_version = current_version
         current_version = get_previous_version(current_version)
     else:
         # Calculate the new version
-        level_bump = evaluate_version_bump(current_version, kwargs['force_level'])
+        level_bump = evaluate_version_bump(current_version, kwargs["force_level"])
         new_version = get_new_version(current_version, level_bump)
 
     owner, name = get_repository_owner_and_name()
 
-    branch = config.get('semantic_release', 'branch')
-    debug('branch=', branch)
+    branch = config.get("semantic_release", "branch")
+    logger.debug(f"Running publish on branch {branch}")
     ci_checks.check(branch)
     checkout(branch)
 
     if version(**kwargs):  # Bump to the new version if needed
         # A new version was released
-        click.echo('Pushing new version')
+        logger.info("Pushing new version")
         push_new_version(
             auth_token=get_token(),
             owner=owner,
@@ -189,55 +218,52 @@ def publish(**kwargs):
         )
 
         # Get config options for uploads
-        dist_path = config.get('semantic_release', 'dist_path')
-        remove_dist = config.getboolean('semantic_release', 'remove_dist')
-        upload_pypi = config.getboolean('semantic_release', 'upload_to_pypi')
-        upload_release = config.getboolean('semantic_release', 'upload_to_release')
+        dist_path = config.get("semantic_release", "dist_path")
+        remove_dist = config.getboolean("semantic_release", "remove_dist")
+        upload_pypi = config.getboolean("semantic_release", "upload_to_pypi")
+        upload_release = config.getboolean("semantic_release", "upload_to_release")
 
         if upload_pypi or upload_release:
             # We need to run the command to build wheels for releasing
-            click.echo('Building distributions')
+            logger.info("Building distributions")
             if remove_dist:
                 # Remove old distributions before building
                 remove_dists(dist_path)
             build_dists()
 
         if upload_pypi:
-            click.echo('Uploading to PyPI')
+            logger.info("Uploading to PyPI")
             upload_to_pypi(
                 path=dist_path,
-                username=os.environ.get('PYPI_USERNAME'),
-                password=os.environ.get('PYPI_PASSWORD'),
                 # If we are retrying, we don't want errors for files that are already on PyPI.
-                skip_existing=retry
+                skip_existing=retry,
             )
 
         if check_token():
             # Update changelog on HVCS
-            click.echo('Updating changelog')
+            logger.info("Posting changelog to HVCS")
             try:
                 log = generate_changelog(current_version, new_version)
                 post_changelog(
                     owner,
                     name,
                     new_version,
-                    markdown_changelog(new_version, log, header=False)
+                    markdown_changelog(new_version, log, header=False),
                 )
             except GitError:
-                click.echo(click.style('Posting changelog failed.', 'red'), err=True)
+                logger.error("Posting changelog failed")
         else:
-            click.echo(
-                click.style('Missing token: cannot post changelog', 'red'), err=True)
+            logger.warning("Missing token: cannot post changelog to HVCS")
 
         # Upload to GitHub Releases
         if upload_release and check_token():
-            click.echo('Uploading to HVCS release')
+            logger.info("Uploading to HVCS release")
             upload_to_release(owner, name, new_version, dist_path)
         # Remove distribution files as they are no longer needed
         if remove_dist:
             remove_dists(dist_path)
 
-        click.echo(click.style('New release published', 'green'))
+        logger.info("New release published")
 
     # else: Since version shows a message on failure, we do not need to print another.
 
@@ -247,17 +273,18 @@ def filter_output_for_secrets(message):
     output = message
     for secret_name in SECRET_NAMES:
         secret = os.environ.get(secret_name)
-        if secret != '' and secret is not None:
-            output = output.replace(secret, '${}'.format(secret_name))
+        if secret != "" and secret is not None:
+            output = output.replace(secret, "${}".format(secret_name))
 
     return output
 
 
 def entry():
     # Move flags to after the command
-    ARGS = sorted(sys.argv[1:], key=lambda x: 1 if x.startswith('--') else -1)
+    ARGS = sorted(sys.argv[1:], key=lambda x: 1 if x.startswith("--") else -1)
     main(args=ARGS)
 
+
 #
 # Making the CLI commands.
 # We have a level of indirection to the logical commands
@@ -268,56 +295,62 @@ def entry():
 @click.group()
 @common_options
 def main(**kwargs):
-    if debug.enabled:
-        debug('main args:', kwargs)
-        message = ''
-        for secret_name in SECRET_NAMES:
-            message += '{}="{}",'.format(secret_name, os.environ.get(secret_name))
-        debug('main env:', filter_output_for_secrets(message))
+    logger.debug("Main args:", kwargs)
+    message = ""
+    for secret_name in SECRET_NAMES:
+        message += '{}="{}",'.format(secret_name, os.environ.get(secret_name))
+    logger.debug("Environment:", filter_output_for_secrets(message))
 
-        obj = {}
-        for key in ['check_build_status', 'commit_subject', 'commit_message', 'commit_parser',
-                    'patch_without_tag', 'upload_to_pypi', 'version_source']:
-            val = config.get('semantic_release', key)
-            obj[key] = val
-        debug('main config:', obj)
+    obj = {}
+    for key in [
+        "check_build_status",
+        "commit_subject",
+        "commit_message",
+        "commit_parser",
+        "patch_without_tag",
+        "upload_to_pypi",
+        "version_source",
+    ]:
+        val = config.get("semantic_release", key)
+        obj[key] = val
+    logger.debug("Main config:", obj)
 
 
-@main.command(name='publish', help=publish.__doc__)
+@main.command(name="publish", help=publish.__doc__)
 @common_options
 def cmd_publish(**kwargs):
     try:
         return publish(**kwargs)
     except Exception as error:
-        click.echo(click.style(filter_output_for_secrets(str(error)), 'red'), err=True)
+        logger.error(filter_output_for_secrets(str(error)))
         exit(1)
 
 
-@main.command(name='changelog', help=changelog.__doc__)
+@main.command(name="changelog", help=changelog.__doc__)
 @common_options
 @click.option(
-    '--unreleased/--released',
-    help="Decides whether to show the released or unreleased changelog."
+    "--unreleased/--released",
+    help="Decides whether to show the released or unreleased changelog.",
 )
 def cmd_changelog(**kwargs):
     try:
         return changelog(**kwargs)
     except Exception as error:
-        click.echo(click.style(filter_output_for_secrets(str(error)), 'red'), err=True)
+        logger.error(filter_output_for_secrets(str(error)))
         exit(1)
 
 
-@main.command(name='version', help=version.__doc__)
+@main.command(name="version", help=version.__doc__)
 @common_options
 def cmd_version(**kwargs):
     try:
         return version(**kwargs)
     except Exception as error:
-        click.echo(click.style(filter_output_for_secrets(str(error)), 'red'), err=True)
+        logger.error(filter_output_for_secrets(str(error)))
         exit(1)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     #
     # Allow options to come BEFORE commands,
     # we simply sort them behind the command instead.
