@@ -1,19 +1,22 @@
 """Legacy commit parser from Python Semantic Release 1.0"""
+import logging
 import re
 from typing import Optional, Tuple
 
 from ..errors import UnknownCommitMessageStyleError
+from ..helpers import LoggedFunction
 from ..settings import config
 from .parser_helpers import ParsedCommit, parse_text_block
 
-re_parser = re.compile(
-    r'(?P<subject>[^\n]+)'
-    r'(:?\n\n(?P<text>.+))?',
-    re.DOTALL
-)
+logger = logging.getLogger(__name__)
+
+re_parser = re.compile(r"(?P<subject>[^\n]+)" r"(:?\n\n(?P<text>.+))?", re.DOTALL)
 
 
-def parse_commit_message(message: str) -> Tuple[int, str, Optional[str], Tuple[str, str, str]]:
+@LoggedFunction(logger)
+def parse_commit_message(
+    message: str,
+) -> Tuple[int, str, Optional[str], Tuple[str, str, str]]:
     """
     Parse a commit message according to the 1.0 version of python-semantic-release.
 
@@ -29,34 +32,34 @@ def parse_commit_message(message: str) -> Tuple[int, str, Optional[str], Tuple[s
     parsed = re_parser.match(message)
     if not parsed:
         raise UnknownCommitMessageStyleError(
-            'Unable to parse the given commit message: {0}'.format(message)
+            "Unable to parse the given commit message: {0}".format(message)
         )
 
-    subject = parsed.group('subject')
+    subject = parsed.group("subject")
 
     # Check tags for minor or patch
-    if config.get('semantic_release', 'minor_tag') in message:
-        level = 'feature'
+    if config.get("semantic_release", "minor_tag") in message:
+        level = "feature"
         level_bump = 2
         if subject:
-            subject = subject.replace(config.get('semantic_release', 'minor_tag'), '')
+            subject = subject.replace(config.get("semantic_release", "minor_tag"), "")
 
-    elif config.get('semantic_release', 'fix_tag') in message:
-        level = 'fix'
+    elif config.get("semantic_release", "fix_tag") in message:
+        level = "fix"
         level_bump = 1
         if subject:
-            subject = subject.replace(config.get('semantic_release', 'fix_tag'), '')
+            subject = subject.replace(config.get("semantic_release", "fix_tag"), "")
 
     else:
         # We did not find any tags in the commit message
         raise UnknownCommitMessageStyleError(
-            'Unable to parse the given commit message: {0}'.format(message)
+            "Unable to parse the given commit message: {0}".format(message)
         )
 
-    if parsed.group('text') and 'BREAKING CHANGE' in parsed.group('text'):
-        level = 'breaking'
+    if parsed.group("text") and "BREAKING CHANGE" in parsed.group("text"):
+        level = "breaking"
         level_bump = 3
 
-    body, footer = parse_text_block(parsed.group('text'))
+    body, footer = parse_text_block(parsed.group("text"))
     descriptions = (subject.strip(), body.strip(), footer.strip())
     return ParsedCommit(level_bump, level, None, descriptions)
